@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mastodon" "2.0.12"
+(define-package "mastodon" "20251117.1458"
   "Client for fediverse services using the Mastodon API."
-  '((emacs   "29.1")
+  '((emacs   "28.1")
     (persist "0.8")
-    (tp      "0.8"))
+    (tp      "0.7"))
   :url "https://codeberg.org/martianh/mastodon.el"
-  :commit "096494056bdb832f9707f3011bffb80fcf8a6d7c"
-  :revdesc "096494056bdb"
+  :commit "1ac040c113c061c173206658657cdee708001471"
+  :revdesc "1ac040c113c0"
   :authors '(("Johnson Denen" . "johnson.denen@gmail.com")
              ("Marty Hiatt" . "mousebot@disroot.org"))
   :maintainers '(("Marty Hiatt" . "mousebot@disroot.org")))
